@@ -5,6 +5,8 @@ from edgedb_orm import is_unset
 
 class BasePatch(BaseModel):
     def updated_fields(self, exclude: T.Set[str] = None) -> T.Set[str]:
+        if exclude is None:
+            exclude = set()
         return {
             field
             for field in self.__fields__
