@@ -76,7 +76,7 @@ def imports(enums_module: str) -> str:
         "from decimal import Decimal",
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
         "from pydantic import BaseModel, Field, PrivateAttr, validator",
-        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str, BasePatch",
+        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str, BasePatch, FilterConnector",
         f"from .{enums_module} import *",
         'EdgeResolverType = T.TypeVar("EdgeResolverType", bound=Resolver)',
     ]
@@ -165,16 +165,16 @@ def build_filter_functions_str(node_name: str, conversion_map: T.Dict[str, dict]
     )
     dict_fields_str = ", ".join([f'"{f}": {f}' for f in field_names])
     filter_by_str = f"""
-def filter_by(self, {params_fields_str}) -> {node_name}Resolver:
-    return super().filter_by(**{{{dict_fields_str}}})
+def filter_by(self, filter_connector: FilterConnector = None, {params_fields_str}) -> {node_name}Resolver:
+    return super().filter_by(connector=filter_connector, **{{{dict_fields_str}}})
     """
     # now for filter in
     params_fields_lst_str = ", ".join(
         [f"{f}: T.Optional[T.List[T.Any]] = None" for f in field_names]
     )
     filter_in_str = f"""
-def filter_in(self, {params_fields_lst_str}) -> {node_name}Resolver:
-    return super().filter_in(**{{{dict_fields_str}}})
+def filter_in(self, filter_connector: FilterConnector = None, {params_fields_lst_str}) -> {node_name}Resolver:
+    return super().filter_in(connector=filter_connector, **{{{dict_fields_str}}})
     """
     return f"{filter_by_str}\n{filter_in_str}"
 
