@@ -453,7 +453,12 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
             # if the cast says they should be strings and they are not, turn them into json
             for field_name, value in d.items():
                 if cast := cls._edgedb_conversion_map.get(field_name, {}).get("cast"):
-                    if cast.endswith("::str") and not isinstance(value, str):
+                    if (
+                        cast.endswith("::str")
+                        and not isinstance(value, str)
+                        and not type(value) in [set]
+                    ):
+                        # if ITERABLE of strs, ignore. For now just SET, cause what if list of objs
                         d[field_name] = json.dumps(jsonable_encoder(value))
             # get fields that are LINKS
             for link_name in cls._link_conversion_map.keys():
