@@ -362,9 +362,14 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             if intersections := set(query_variables.keys()).intersection(
                 set(nested_query_variables.keys())
             ):
-                raise ResolverException(
-                    f"'{', '.join(intersections)}' query value(s) used multiple times."
-                )
+                for intersection_key in intersections:
+                    if (
+                        query_variables[intersection_key]
+                        != nested_query_variables[intersection_key]
+                    ):
+                        raise ResolverException(
+                            f"'{intersection_key}' query value used multiple times with different value."
+                        )
             query_variables = {**query_variables, **nested_query_variables}
         return query_variables
 
